summaryrefslogtreecommitdiffstats
path: root/sys/powerpc/include/pcpu.h
diff options
context:
space:
mode:
Diffstat (limited to 'sys/powerpc/include/pcpu.h')
-rw-r--r--sys/powerpc/include/pcpu.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/sys/powerpc/include/pcpu.h b/sys/powerpc/include/pcpu.h
index 4d37de4..c222ee0 100644
--- a/sys/powerpc/include/pcpu.h
+++ b/sys/powerpc/include/pcpu.h
@@ -33,10 +33,13 @@
#ifdef _KERNEL
#include <machine/cpufunc.h>
+struct pmap;
+
#define PCPU_MD_FIELDS \
int pc_inside_intr; \
u_int32_t pc_next_asn; /* next ASN to alloc */ \
- u_int32_t pc_current_asngen /* ASN rollover check */
+ u_int32_t pc_current_asngen; /* ASN rollover check */\
+ struct pmap *pc_curpmap /* current pmap */
#define PCPUP ((struct pcpu *) powerpc_get_pcpup())
OpenPOWER on IntegriCloud